
/* Generated data (by glib-mkenums) */

#ifndef __CLUTTER_X11_ENUM_TYPES_H__
#define __CLUTTER_X11_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../../clutter/x11/clutter-x11.h" */
GType clutter_x11_filter_return_get_type (void) G_GNUC_CONST;
#define CLUTTER_X11_TYPE_X11_FILTER_RETURN (clutter_x11_filter_return_get_type())

GType clutter_x11_xinput_event_types_get_type (void) G_GNUC_CONST;
#define CLUTTER_X11_TYPE_X11_XINPUT_EVENT_TYPES (clutter_x11_xinput_event_types_get_type())

G_END_DECLS

#endif /* !__CLUTTER_X11_ENUM_TYPES_H__ */

/* Generated data ends here */

